cnr_reproject: Reproject a layer where each cell takes the first value which...

Description Usage Arguments Value

Description

Reproject a layer where each cell takes the first value which is not NaN (ie is numerical)

Usage

1
cnr_reproject(r, crs_from)

Arguments

r

rast

crs_from

valid EPSG crs string

Value

flattened raster


raquamaps/cnr documentation built on Dec. 22, 2021, 12:57 p.m.